@@ -368,7 +368,7 @@ class DSLibrary(object):
         """
         Save a piece of trackable information about this run.
         """
-        if self._mlflow_metrics or self._mlflow_all:
+        if self._mlflow_metrics:
             if mlflow:
                 mlflow.log_metric(metric_name, metric_value, step)
             return
@@ -412,7 +412,7 @@ class DSLibrary(object):
         :param limit:           Maximum number of results to return.
         :returns:   An iterable of records (type 'Metric') describing each metric.
         """
-        use_mlflow = self._mlflow_opts.get("metrics") or self._mlflow_all
+        use_mlflow = self._mlflow_metrics
         if use_mlflow:
             # TODO to support this would require creating a client, using the run ID to look them up, etc.
             raise DSLibraryException("Access to metrics in mlflow is not supported at this time.")
@@ -428,16 +428,15 @@ class DSLibrary(object):
         df.sort_values(by=["time"], ascending=False)
         if limit:
             df = df.head(limit)
-        return df
+        return df.itertuples(index=False, name="Metrics")
 
     def get_last_metric(self, metric_name: str):
         """
         Get the most recently saved metric of the given name for the current model.
         """
-        metrics = self.get_metrics(metric_name, uri=self.get_uri(), limit=1)
-        if metrics.shape[0]:
-            row = metrics.iloc[0]
-            return DSLibrary.Metric(**row)
+        metrics = list(self.get_metrics(metric_name, uri=self.get_uri(), limit=1))
+        if metrics:
+            return DSLibrary.Metric(*metrics[0])
 
     def log_text(self, text: str, artifact_file: str):
         """
