@@ -7,6 +7,7 @@ import pandas
 import shutil
 import tempfile
 import yaml
+import time
 import dask.dataframe
 
 from dslibrary import DSLibrary
@@ -104,9 +105,15 @@ class TestFront(unittest.TestCase):
         The normal use case is have the caller supply all the connection information.
         """
         dsl = DSLibrary(spec={"inputs": {"db": {"uri": "mysql://host/db", "username": "u"}}})
+        class C(object):
+            _flavor = None
+        def connect(**k):
+            self.assertEqual(k, {'user': 'u', 'password': '', 'host': 'host', 'port': 3306, 'database': 'db', 'autocommit': True})
+            return C()
         with mock.patch("pymysql.connect", connect):
             r = dsl.get_sql_connection("db")
-            assert r == "CONN"
+            assert isinstance(r, C)
+            assert r._flavor == "mysql"
 
     def test_load_dataframe_from_sql__flavors(self):
         """
@@ -419,9 +426,24 @@ class TestFront(unittest.TestCase):
             self.assertEqual(fs, "SqlConn")
         self.assertEqual(log, [{'uri': 'resource', 'library': None, 'for_write': True, 'arg1': 123}])
 
+    def test_metrics(self):
+        tmpf = tempfile.mkdtemp()
+        inst = DSLibraryLocal(tmpf)
+        inst.log_metric("x", 123)
+        r = list(inst.get_metrics("x"))
+        self.assertEqual(len(r), 1)
+        self.assertEqual(r[0].name, "x")
+        self.assertEqual(r[0].value, 123)
+        self.assertAlmostEqual(r[0].time, time.time(), delta=1)
+        r = inst.get_last_metric("x")
+        self.assertEqual(r.name, "x")
+        self.assertEqual(r.value, 123)
+        self.assertAlmostEqual(r.time, time.time(), delta=1)
+        shutil.rmtree(tmpf)
+
     def test_log_mlflow(self):
         inst = DSLibrary()
-        inst._mlflow_all = True
+        inst._mlflow_all = inst._mlflow_metrics = True
         log = []
         with mock.patch("mlflow.log_param", lambda k, v: log.append((k, v))):
             inst.log_param("x", 1)
