@@ -178,3 +178,22 @@ class TestToMMLibrary(unittest.TestCase):
         dsl = DSLibraryViaMMLibrary(_mm=MyMM())
         r = dsl.open_resource("name", mode="r", filesystem="fs123", bucket_name="b1")
         assert r.read() == "xyz"
+
+    def test_metrics(self):
+        m = {}
+        class MyMM(object):
+            def save_kpi(self, metric_name, metric_value):
+                m[metric_name] = metric_value
+            def get_last_kpi(self, metric_name):
+                return {"value": m[metric_name], "timestamp": 1000000}
+        dsl = DSLibraryViaMMLibrary(_mm=MyMM())
+        dsl.log_metric("x", 123)
+        r = dsl.get_metrics("x")
+        self.assertEqual(len(r), 1)
+        self.assertEqual(r[0].name, "x")
+        self.assertEqual(r[0].value, 123)
+        self.assertEqual(r[0].time, 1000000)
+        r = dsl.get_last_metric("x")
+        self.assertEqual(r.name, "x")
+        self.assertEqual(r.value, 123)
+        self.assertEqual(r.time, 1000000)
